tests Package
=============

:mod:`tests` Package
--------------------

.. automodule:: CMFDefault.upgrade.tests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_syndication_upgrade` Module
--------------------------------------

.. automodule:: CMFDefault.upgrade.tests.test_syndication_upgrade
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_upgrade` Module
--------------------------

.. automodule:: CMFDefault.upgrade.tests.test_upgrade
    :members:
    :undoc-members:
    :show-inheritance:

